import { FrameButton, Frame, SupportedParsingSpecification, getFrame, TransactionTargetResponse } from 'frames.js';
import { CastId, FrameActionMessage } from '@farcaster/core';

type FarcasterSignerState = SignerStateInstance<FarcasterSigner | null>;
interface FarcasterSigner {
    privateKey: string;
    publicKey: string;
    fid?: number;
    /** The status of the signer */
    status: "approved" | "pending_approval" | "impersonating";
    signature?: string;
    deadline?: number;
    signerApprovalUrl?: string;
    token?: any;
}
declare const mockFarcasterSigner: FarcasterSigner;

type FarcasterFrameContext = {
    /** Connected address of user, only sent with transaction data request */
    address?: `0x${string}`;
    castId: {
        hash: `0x${string}`;
        fid: number;
    };
};
/** Creates a frame action for use with `useFrame` and a proxy */
declare const signFrameAction: ({ buttonIndex, frameContext, frameButton, signer, target, inputText, state, transactionId, url, }: {
    target?: string | undefined;
    frameButton: FrameButton;
    buttonIndex: number;
    url: string;
    signer: FarcasterSignerState["signer"];
    inputText?: string | undefined;
    state?: string | undefined;
    transactionId?: `0x${string}` | undefined;
    frameContext: FarcasterFrameContext;
}) => Promise<{
    body: FrameActionBodyPayload;
    searchParams: URLSearchParams;
}>;
declare function createFrameActionMessageWithSignerKey(signerKey: string, { fid, url, buttonIndex, castId, inputText, state, address, transactionId, }: {
    fid: number;
    url: Uint8Array;
    buttonIndex: number;
    inputText: Uint8Array | undefined;
    castId: CastId;
    state: Uint8Array | undefined;
    address: Uint8Array | undefined;
    transactionId: Uint8Array | undefined;
}): Promise<{
    message: null;
    trustedBytes: null;
} | {
    message: FrameActionMessage | null;
    trustedBytes: string;
}>;

type OnTransactionFunc = (t: OnTransactionArgs) => Promise<`0x${string}` | null>;
type UseFrameReturn<SignerStorageType = object, FrameActionBodyType extends FrameActionBodyPayload = FrameActionBodyPayload, FrameContextType extends FrameContext = FarcasterFrameContext> = {
    /** skip frame signing, for frames that don't verify signatures */
    dangerousSkipSigning?: boolean;
    /** the route used to POST frame actions. The post_url will be added as a the `url` query parameter */
    frameActionProxy: string;
    /** the route used to GET the initial frame via proxy */
    frameGetProxy: string;
    /** an signer state object used to determine what actions are possible */
    signerState: SignerStateInstance<SignerStorageType, FrameActionBodyType, FrameContextType>;
    /** the url of the homeframe, if null / undefined won't load a frame */
    homeframeUrl: string | null | undefined;
    /** the initial frame. if not specified will fetch it from the url prop */
    frame?: Frame;
    /** connected wallet address of the user */
    connectedAddress: `0x${string}` | undefined;
    /** a function to handle mint buttons */
    onMint?: (t: OnMintArgs) => void;
    /** a function to handle transaction buttons, returns the transaction hash or null */
    onTransaction?: OnTransactionFunc;
    /** the context of this frame, used for generating Frame Action payloads */
    frameContext: FrameContextType;
    /**
     * Extra data appended to the frame action payload
     */
    extraButtonRequestPayload?: Record<string, unknown>;
    /**
     * Which specification to use for parsing the frame action payload
     *
     * @defaultValue 'farcaster'
     */
    specification?: SupportedParsingSpecification;
};
interface SignerStateInstance<SignerStorageType = object, FrameActionBodyType extends FrameActionBodyPayload = FrameActionBodyPayload, FrameContextType extends FrameContext = FarcasterFrameContext> {
    signer?: SignerStorageType | null;
    hasSigner: boolean;
    signFrameAction: (actionContext: {
        target?: string;
        frameButton: FrameButton;
        buttonIndex: number;
        url: string;
        inputText?: string;
        signer: SignerStorageType | null;
        state?: string;
        transactionId?: `0x${string}`;
        address?: `0x${string}`;
        frameContext: FrameContextType;
    }) => Promise<{
        body: FrameActionBodyType;
        searchParams: URLSearchParams;
    }>;
    /** isLoading frame */
    isLoading?: null | FrameStackPending;
    /** is loading the signer */
    isLoadingSigner?: boolean;
    /** A function called when a frame button is clicked without a signer */
    onSignerlessFramePress: () => void;
    logout?: () => void;
}
type FrameRequest = {
    method: "GET";
    url: string;
} | {
    method: "POST";
    request: {
        body: object;
        searchParams: URLSearchParams;
    };
    url: string;
};
type FrameStackBase = {
    timestamp: Date;
    /** speed in seconds */
    speed: number;
    responseStatus: number;
} & FrameRequest;
type FrameStackPending = {
    timestamp: Date;
    status: "pending";
} & FrameRequest;
type GetFrameResult = ReturnType<typeof getFrame>;
type FrameStackDone = FrameStackBase & {
    frame: GetFrameResult;
    status: "done";
};
type FrameStackRequestError = FrameStackBase & {
    status: "requestError";
    requestError: unknown;
};
type FramesStackItem = FrameStackPending | FrameStackDone | FrameStackRequestError;
type FramesStack = FramesStackItem[];
type FrameState = {
    fetchFrame: (request: FrameRequest) => void | Promise<void>;
    clearFrameStack: () => void;
    /** The frame at the top of the stack (at index 0) */
    frame: FramesStackItem | undefined;
    /** A stack of frames with additional context, with the most recent frame at index 0 */
    framesStack: FramesStack;
    inputText: string;
    setInputText: (s: string) => void;
    onButtonPress: (frame: Frame, frameButton: FrameButton, index: number) => void | Promise<void>;
    homeframeUrl: string | null | undefined;
};
type OnMintArgs = {
    target: string;
    frameButton: FrameButton;
    frame: Frame;
};
type OnTransactionArgs = {
    transactionData: TransactionTargetResponse;
    frameButton: FrameButton;
    frame: Frame;
};
declare const themeParams: readonly ["bg", "buttonColor", "buttonBg", "buttonBorderColor", "buttonRadius", "buttonHoverBg"];
type FrameTheme = Partial<Record<(typeof themeParams)[number], string>>;
type FrameActionBodyPayload = Record<string, unknown>;
type FrameContext = Record<string, unknown>;

export { type FarcasterFrameContext as F, type GetFrameResult as G, type OnTransactionFunc as O, type SignerStateInstance as S, type UseFrameReturn as U, type FarcasterSignerState as a, type FarcasterSigner as b, createFrameActionMessageWithSignerKey as c, type FrameRequest as d, type FrameStackBase as e, type FrameStackPending as f, type FrameStackDone as g, type FrameStackRequestError as h, type FramesStackItem as i, type FramesStack as j, type FrameState as k, type OnMintArgs as l, mockFarcasterSigner as m, type OnTransactionArgs as n, type FrameTheme as o, type FrameActionBodyPayload as p, type FrameContext as q, signFrameAction as s, themeParams as t };
